@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.20.0';
+our $VERSION = '1.2.22.0';
 
 use Exporter 'import';
 
@@ -31,6 +31,8 @@ use Search::Xapian::BM25Weight;
 use Search::Xapian::BoolWeight;
 use Search::Xapian::TradWeight;
 
+use Search::Xapian::ValueCountMatchSpy;
+
 use Search::Xapian::SimpleStopper;
 use Search::Xapian::PerlStopper;
 
@@ -472,6 +474,11 @@ Please report any bugs/suggestions to E<lt>xapian-discuss@lists.xapian.orgE<gt>
 or use the Xapian bug tracker L<http://xapian.org/bugs>.  Please do
 NOT use the CPAN bug tracker or mail any of the authors individually.
 
+=head1 LICENSE
+
+This program is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
 =head1 SEE ALSO
 
 L<Search::Xapian::BM25Weight>,
@@ -479,6 +486,7 @@ L<Search::Xapian::BoolWeight>,
 L<Search::Xapian::Database>,
 L<Search::Xapian::Document>,
 L<Search::Xapian::Enquire>,
+L<Search::Xapian::MatchSpy>,
 L<Search::Xapian::MultiValueSorter>,
 L<Search::Xapian::PositionIterator>,
 L<Search::Xapian::PostingIterator>,
